@@ -1,4 +1,4 @@
-# ABSTRACT: check for differences between base scan and now
+# ABSTRACT: check for differences by comparing base scan and actual state
 package App::Monport::Command::diff;
 use App::Monport -command;
 use App::Monport::Nmap;
@@ -28,6 +28,7 @@ Options.
 sub options {
   return (
     [ "email|m=s@", "send differences via email instead of printing them to stdout", ],
+    [ 'nmapexe|e=s', "nmap executable (default: '/usr/bin/nmap')", { default => "/usr/bin/nmap" } ],
   );
 }
 
