@@ -8,16 +8,19 @@ use File::Path qw(make_path);
 use Nmap::Parser;
 use File::Basename qw(basename);
 use Sys::Hostname qw(hostname);
+use Email::MIME;
+use Email::Sender::Simple;
+use File::Spec::Functions;
 
 our @EXPORT =
   qw(list_basescans set_vars do_basescan print_basescan email_diffs print_diffs);
 
-my $base_dir = "$ENV{HOME}/.monport";
+our $base_dir = catfile $ENV{HOME}, ".monport";
 
-my $scan_name;
-my $nmap_exe;
-my $path;
-my $base_file;
+our $scan_name;
+our $nmap_exe;
+our $path;
+our $base_file;
 
 =head1 DESCRIPTION
 
@@ -34,10 +37,10 @@ Set variables for this package.
 sub set_vars {
     ( $scan_name, $nmap_exe ) = @_;
 
-    $scan_name =~ s/\s+/_/g;
+    $scan_name =~ s/\s/_/g;
 
-    $path      = "$base_dir/$scan_name";
-    $base_file = "$path/base.xml";
+    $path      = catfile $base_dir, $scan_name;
+    $base_file = catfile $path,     "base.xml";
 }
 
 =head2 email_diffs( @email_addresses )
@@ -55,41 +58,6 @@ sub email_diffs {
     }
 }
 
-=head2 loadModule( $module )
-
-Try to load a $module at runtime. Return 1 on success 0 otherwise. $module can
-be 'Module::Name' or 'Module/Name.pm'.
-
-Loading error is stored in C<$@> and can propagate to die() if die() is
-use without arguments:
-
-    loadModule( $module ) or die;
-
-=cut
-
-sub loadModule {
-    my $module = shift;
-
-    # require doesn't work with Module::Name stored in a variable so we turn it
-    # into Module/Name.pm
-    $module = File::Spec->catfile( split( /::/, $module ) ) . '.pm'
-      if $module =~ /::/;
-
-    eval {
-        require $module;
-        $module->import;
-        1;
-    };
-
-    if ($@) {
-
-        #print STDERR "Failed to load $module because: $@";
-        return 0;
-    } else {
-        return 1;
-    }
-}
-
 =head2 sendMail( $to, $subject, $body )
 
 Send email. Based on L<http://perldoc.perl.org/perlfaq9.html>.
@@ -99,12 +67,6 @@ Send email. Based on L<http://perldoc.perl.org/perlfaq9.html>.
 sub sendMail {
     my ( $receiver, $subject, $mail_body ) = @_;
 
-    # We need these modules
-    my @modules = qw( Email::MIME Email::Sender::Simple );
-    for (@modules) {
-        loadModule($_) or die;
-    }
-
     # sender will the user running the program
     my $host  = hostname;
     my $login = getlogin || getpwuid($<) || "uknown";
@@ -146,7 +108,7 @@ List names of available base(line) scans.
 =cut
 
 sub list_basescans {
-    for my $dir ( glob "$base_dir/*" ) {
+    for my $dir ( glob catfile( $base_dir, '*' ) ) {
         ( my $name = basename $dir) =~ s/_/ /g;
         print "$name\n";
     }
